@@ -358,7 +358,7 @@ class Game(GameNode):
         Unless the `SetUp` and `FEN` header tags are set this is the default
         starting position.
         """
-        if "FEN" in self.headers and "SetUp" in self.headers and self.headers["SetUp"] == "1":
+        if "FEN" in self.headers and self.headers.get("SetUp", "1") == "1":
             chess960 = self.headers.get("Variant") == "Chess960"
             board = chess.Board(self.headers["FEN"], chess960=chess960)
             board.chess960 = board.chess960 or board.has_chess960_castling_rights()
@@ -549,8 +549,8 @@ class StringExporter(BaseVisitor):
     """
     Allows exporting a game as a string.
 
-    >>> exporter = chess.pgn.StringExporter()
-    >>> pgn_string = game.accept(exporter, headers=True, variations=True, comments=True)
+    >>> exporter = chess.pgn.StringExporter(headers=True, variations=True, comments=True)
+    >>> pgn_string = game.accept(exporter)
 
     Only *columns* characters are written per line. If *columns* is ``None``
     then the entire movetext will be on a single line. This does not affect
